const { join } = require('path');
const { nodeFileTrace } = require('@vercel/nft');
const { writeJSON, readJSON, readdir } = require('fs-extra');
const { HANDLER_FUNCTION_NAME } = require('../constants');
exports.traceDependencies = async ({ constants, netlifyConfig, target, run }) => {
    // We use the repo root as the base directory for the trace, because it excludes
    // any files above the root, and in a monorepo there may be deps in a parent
    const { stdout: base } = await run('git', ['rev-parse', '--show-toplevel']);
    console.time('Tracing dependencies');
    const root = join(netlifyConfig.build.publish, target === 'server' ? 'server' : 'serverless');
    const pagesManifest = await readJSON(join(root, 'pages-manifest.json'));
    const pagefiles = [join(constants.INTERNAL_FUNCTIONS_SRC, HANDLER_FUNCTION_NAME, `${HANDLER_FUNCTION_NAME}.js`)];
    for (const page in pagesManifest) {
        const file = pagesManifest[page];
        if (file.endsWith('.js')) {
            pagefiles.push(join(root, file));
        }
    }
    const { fileList } = await nodeFileTrace(pagefiles, { ignore: ['node_modules/chokidar/*'], base });
    const files = fileList.map((file) => join(base, file));
    console.timeEnd('Tracing dependencies');
    return files;
};
